@@ -5,7 +5,17 @@ import os
 import sys
 import time
 
-from .downloader import YoutubeCommentDownloader, SORT_BY_RECENT
+from .downloader import YoutubeCommentDownloader, SORT_BY_POPULAR, SORT_BY_RECENT
+
+INDENT = 4
+
+
+def to_json(comment, indent=None):
+    comment_str = json.dumps(comment, ensure_ascii=False, indent=indent)
+    if indent is None:
+        return comment_str
+    padding = ' ' * (2 * indent) if indent else ''
+    return ''.join(padding + line for line in comment_str.splitlines(True))
 
 
 def main(argv = None):
@@ -14,6 +24,7 @@ def main(argv = None):
     parser.add_argument('--youtubeid', '-y', help='ID of Youtube video for which to download the comments')
     parser.add_argument('--url', '-u', help='Youtube URL for which to download the comments')
     parser.add_argument('--output', '-o', help='Output filename (output format is line delimited JSON)')
+    parser.add_argument('--pretty', '-p', action='store_true', help='Change the output format to indented JSON')
     parser.add_argument('--limit', '-l', type=int, help='Limit the number of comments')
     parser.add_argument('--language', '-a', type=str, default=None, help='Language for Youtube generated text (e.g. en)')
     parser.add_argument('--sort', '-s', type=int, default=SORT_BY_RECENT,
@@ -26,6 +37,7 @@ def main(argv = None):
         youtube_url = args.url
         output = args.output
         limit = args.limit
+        pretty = args.pretty
 
         if (not youtube_id and not youtube_url) or not output:
             parser.print_usage()
@@ -43,19 +55,28 @@ def main(argv = None):
             if youtube_id
             else downloader.get_comments_from_url(youtube_url, args.sort, args.language)
         )
-        count = 0
+
+        count = 1
         with io.open(output, 'w', encoding='utf8') as fp:
             sys.stdout.write('Downloaded %d comment(s)\r' % count)
             sys.stdout.flush()
             start_time = time.time()
-            for comment in generator:
-                comment_json = json.dumps(comment, ensure_ascii=False)
-                print(comment_json.decode('utf-8') if isinstance(comment_json, bytes) else comment_json, file=fp)
-                count += 1
+
+            if pretty:
+                fp.write('{\n' + ' ' * INDENT + '"comments": [\n')
+
+            comment = next(generator, None)
+            while comment:
+                comment_str = to_json(comment, indent=INDENT if pretty else None)
+                comment = None if limit and count >= limit else next(generator, None)  # Note that this is the next comment
+                comment_str = comment_str + ',' if pretty and comment is not None else comment_str
+                print(comment_str.decode('utf-8') if isinstance(comment_str, bytes) else comment_str, file=fp)
                 sys.stdout.write('Downloaded %d comment(s)\r' % count)
                 sys.stdout.flush()
-                if limit and count >= limit:
-                    break
+                count += 1
+
+            if pretty:
+                fp.write(' ' * INDENT +']\n}')
         print('\n[{:.2f} seconds] Done!'.format(time.time() - start_time))
 
     except Exception as e:
